# Geneve

This is the data generator core module, it does the following tasks:

1. Analyzes the data model
   1. Creates a syntax tree of the query
   2. Collects, validates and optimizes the constraints
2. Creates the data generator

With the data generator you can generate data over and over.

For a short intro, see the
[Rule-based events generation walk-through](https://github.com/elastic/geneve/blob/main/docs/events_generation_walk-through.ipynb).
